@@ -37,7 +37,8 @@ class APIServerClientUtil(object):
                                                                      gateway_id=gateway_id)
         else:
             self.token = self.authenticator.get_token_and_user_info_password_flow(username=username,
-                                                                              password=password, gateway_id=gateway_id)
+                                                                                  password=password,
+                                                                                  gateway_id=gateway_id)
         self.gateway_id = gateway_id
         self.username = username
         self.api_server_client = APIServerClient(configuration_file_location)
@@ -76,3 +77,12 @@ class APIServerClientUtil(object):
             if response[k] == storage_name:
                 return k
         return None
+
+    def get_queue_names(self, resource_host_id):
+        resource = self.api_server_client.get_compute_resource(self.token, resource_host_id)
+        batchqueues = resource.batchQueues
+        allowed_queue_names = []
+        for queue in batchqueues:
+            allowed_queue_names.append(queue.queueName)
+        return allowed_queue_names
+
